<?php

namespace App\Services\goods;

use App\Exception\custom\GoodsException;
use App\Models\goods\mysql\GoodsSpu;
use App\Models\goods\mysql\Setmeal;
use App\Models\goods\mysql\Stores;

class SetmealService
{
    /**
     * @param array $params
     * 编辑套餐
     * @return \Api\PhpUtils\Mysql\MysqlBase
     * @throws GoodsException
     */
    public static function editSetmeal($params = [])
    {
        $lifeAccountId = $params["life_account_id"];
        $goodsSkuId = $params["good_sku_id"];
        $setmealData = json_decode($params['setmeal_data'], true);

        Setmeal::beginTransaction();
        $updateData = $insertData = [];
        foreach ($setmealData as $key => $setmeal) {
            if (empty($setmeal["name"]) || empty($setmeal["unit"]) || empty($setmeal["unit_number"]) || empty($setmeal["unit_price"])) {
                throw new GoodsException(['cus' => 8]);
            }
            if (!empty($setmeal["setmeal_id"])) {
                $updateData[] = [
                    'setmeal_id' => $setmeal["setmeal_id"],
                    'life_account_id' => $lifeAccountId,
                    'goods_sku_id' => $goodsSkuId,
                    'name' => $setmeal["name"],
                    'unit' => $setmeal["unit"],
                    'unit_number' => $setmeal["unit_number"],
                    'unit_price' => $setmeal["unit_price"] * 100,
                ];
            } else {
                $insertData[] = [
                    'life_account_id' => $lifeAccountId,
                    'goods_sku_id' => $goodsSkuId,
                    'name' => $setmeal["name"],
                    'unit' => $setmeal["unit"],
                    'unit_number' => $setmeal["unit_number"],
                    'unit_price' => $setmeal["unit_price"] * 100,
                ];
            }
        }

        if (!empty($insertData)) {
            $ids = GoodsService::getIdgenId(substr($lifeAccountId, -2), "goods", count($insertData));
            if (empty($ids)) {
                throw new GoodsException(['cus' => 6]);
            }
            foreach ($insertData as $insertKey => $item) {
                //判断重复
                $setmeal = Setmeal::getRecordMaster(["goods_sku_id"=>$goodsSkuId, "name"=>$item["name"]]);
                if (!empty($setmeal)) {
                    throw new GoodsException(['cus' => 7]);
                }

                $item["setmeal_id"] = $ids[$insertKey];
                Setmeal::save($item);
            }
        }

        if (!empty($updateData)) {
            foreach ($updateData as $item) {
                //todo::update去重
                $where = [];
                $where["setmeal_id"] = $item["setmeal_id"];
                unset($item["setmeal_id"]);
                Setmeal::save($item, $where);
            }
        }

        if (!Setmeal::commit()) {
            Setmeal::rollback();
            throw new GoodsException(["cus" => 5]);
        }
    }

    /**
     * @param $goodSkuId
     * @return \Api\PhpUtils\Mysql\MysqlBase
     */
    public static function getSetmealList($goodSkuId)
    {
        $list = Setmeal::getAll($goodSkuId);
        if (!empty($list)) {
            foreach ($list as $key => $item) {
                $list[$key]["unit_price"] = $item["unit_price"] / 100;
            }
        }
        return $list;
    }
}